@@ -21,3 +21,8 @@ def test_validate_csv_organization():
     resource_list = ocldev.oclresourcelist.OclCsvResourceList(resources)
     resource_list.validate()
     assert True == True
+
+def test_validate_csv_file():
+    filename = 'sample.csv'
+    resource_list = ocldev.oclresourcelist.OclCsvResourceList.load_from_file(filename)
+    resource_list.validate()
